pub struct AnyOwned { /* private fields */ }Expand description
Owned executable open-type value.
This is the representation used by the recursive BER ANY parser: an indefinite-length constructed value has no single borrowed content slice once its terminating EOC is removed.
Implementations
Sourceimpl AnyOwned
impl AnyOwned
Sourcepub exec fn new(tag: Tag, content: Vec<u8>) -> value : Self
pub exec fn new(tag: Tag, content: Vec<u8>) -> value : Self
ensures
value.deep_view()
== (AnySpec {
tag,
content: content.deep_view(),
}),Sourcepub exec fn content(&self) -> content : &[u8] ⓘ
pub exec fn content(&self) -> content : &[u8] ⓘ
ensures
content.deep_view() == self.deep_view().content,Sourcepub exec fn into_content(self) -> content : Vec<u8> ⓘ
pub exec fn into_content(self) -> content : Vec<u8> ⓘ
ensures
content.deep_view() == self.deep_view().content,Trait Implementations
Sourceimpl<const DER: bool> ByteLen<AnyOwned> for AnyFmt<DER>
Available on crate feature alloc only.
impl<const DER: bool> ByteLen<AnyOwned> for AnyFmt<DER>
Available on crate feature
alloc only.Sourceimpl<const LIMIT: usize> ByteLen<AnyOwned> for BerAnyFmt<LIMIT>
Available on crate feature alloc only.
impl<const LIMIT: usize> ByteLen<AnyOwned> for BerAnyFmt<LIMIT>
Available on crate feature
alloc only.Sourceimpl<const DER: bool> Prepare<AnyOwned> for AnyFmt<DER>
Available on crate feature alloc only.
impl<const DER: bool> Prepare<AnyOwned> for AnyFmt<DER>
Available on crate feature
alloc only.Sourceimpl<const LIMIT: usize> Prepare<AnyOwned> for BerAnyFmt<LIMIT>
Available on crate feature alloc only.
impl<const LIMIT: usize> Prepare<AnyOwned> for BerAnyFmt<LIMIT>
Available on crate feature
alloc only.Sourceimpl<Output: OutputBuf, const DER: bool> Serializer<Output, AnyOwned> for AnyFmt<DER>
Available on crate feature alloc only.
impl<Output: OutputBuf, const DER: bool> Serializer<Output, AnyOwned> for AnyFmt<DER>
Available on crate feature
alloc only.Sourceexec fn serialize_into(&self, v: &AnyOwned, obuf: &mut Output)
exec fn serialize_into(&self, v: &AnyOwned, obuf: &mut Output)